"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getElasticsearchOperators = exports.getElasticsearchOperatorPluginsByLocale = void 0;
var _operator = require("./plugins/operator");
var _ElasticsearchQueryBuilderOperatorPlugin = require("./plugins/definition/ElasticsearchQueryBuilderOperatorPlugin");
const operators = [new _operator.ElasticsearchQueryBuilderOperatorBetweenPlugin(), new _operator.ElasticsearchQueryBuilderOperatorNotBetweenPlugin(), new _operator.ElasticsearchQueryBuilderOperatorContainsPlugin(), new _operator.ElasticsearchQueryBuilderOperatorNotContainsPlugin(), new _operator.ElasticsearchQueryBuilderOperatorEqualPlugin(), new _operator.ElasticsearchQueryBuilderOperatorNotPlugin(), new _operator.ElasticsearchQueryBuilderOperatorGreaterThanPlugin(), new _operator.ElasticsearchQueryBuilderOperatorGreaterThanOrEqualToPlugin(), new _operator.ElasticsearchQueryBuilderOperatorLesserThanPlugin(), new _operator.ElasticsearchQueryBuilderOperatorLesserThanOrEqualToPlugin(), new _operator.ElasticsearchQueryBuilderOperatorInPlugin(), new _operator.ElasticsearchQueryBuilderOperatorAndInPlugin(), new _operator.ElasticsearchQueryBuilderOperatorNotInPlugin(), new _operator.ElasticsearchQueryBuilderOperatorStartsWithPlugin(), new _operator.ElasticsearchQueryBuilderOperatorNotStartsWithPlugin(),
/**
 * Japanese
 */
new _operator.ElasticsearchQueryBuilderJapaneseOperatorContainsPlugin()];
/**
 * We export as a function because there might be something to be sent to the operators at some point.
 * This way, we make it easier to upgrade.
 */
const getElasticsearchOperators = () => operators;
exports.getElasticsearchOperators = getElasticsearchOperators;
const getElasticsearchOperatorPluginsByLocale = (plugins, locale) => {
  /**
   * We always set the last one operator plugin added.
   * This way user can override the plugins.
   */
  return plugins.byType(_ElasticsearchQueryBuilderOperatorPlugin.ElasticsearchQueryBuilderOperatorPlugin.type).reduce((acc, plugin) => {
    const op = plugin.getOperator();
    /**
     * We only allow the plugins which can pass the locale test.
     * The default plugins always return true.
     */
    if (plugin.isLocaleSupported(locale) === false) {
      return acc;
    }
    /**
     * We also only allow the override of the plugins if the new plugin is NOT a default one.
     * If a user names the plugin with .default, we cannot do anything about it.
     */
    if (!!acc[op] && (plugin.name || "").match(/\.default$/)) {
      return acc;
    }
    acc[op] = plugin;
    return acc;
  }, {});
};
exports.getElasticsearchOperatorPluginsByLocale = getElasticsearchOperatorPluginsByLocale;

//# sourceMappingURL=operators.js.map