"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ElasticsearchFieldPlugin = void 0;
var _plugins = require("@webiny/plugins");
const keywordLessUnmappedType = ["date", "long"];
const unmappedTypeHasKeyword = type => {
  if (!type) {
    return true;
  } else if (keywordLessUnmappedType.includes(type)) {
    return false;
  }
  return true;
};
class ElasticsearchFieldPlugin extends _plugins.Plugin {
  static type = "elasticsearch.fieldDefinition";
  static ALL = "*";
  constructor(params) {
    super();
    this.field = params.field;
    this.path = params.path || params.field;
    this.keyword = params.keyword === undefined ? true : params.keyword;
    this.unmappedType = params.unmappedType;
    if (unmappedTypeHasKeyword(params.unmappedType) === false) {
      this.keyword = false;
    }
    this.sortable = params.sortable === undefined ? true : params.sortable;
    this.searchable = params.searchable === undefined ? true : params.searchable;
  }
  /**
   * The default sort options. Extend in your own plugin if you want to add more options.
   */
  getSortOptions(order) {
    const options = {
      order
    };
    if (!this.unmappedType) {
      return options;
    }
    return {
      ...options,
      unmapped_type: this.unmappedType
    };
  }
  /**
   * The default path generator. Extend in your own plugin if you want to add more options.
   * Field parameter is here because there is a possibility that this is the ALL field plugin, so we need to know which field are we working on.
   */
  getPath(field) {
    return `${this.getBasePath(field)}${this.keyword ? ".keyword" : ""}`;
  }
  /**
   * @see getPath
   *
   * This is the default base path generator. Basically it replaces ALL with given field name.
   */
  getBasePath(field) {
    if (this.path === ElasticsearchFieldPlugin.ALL) {
      return field;
    }
    return this.path;
  }
  /**
   * The default transformer. Just returns the value by default.
   * Override to implement what ever is required.
   */
  toSearchValue(params) {
    return params.value;
  }
}
exports.ElasticsearchFieldPlugin = ElasticsearchFieldPlugin;

//# sourceMappingURL=ElasticsearchFieldPlugin.js.map